==> messagelib-16.12.0.tar.xz: messagelib-16.12.0/mimetreeparser/src/bodyformatter/multipartencrypted.h <==
/*
   Copyright (c) 2016 Sandro Knauß <sknauss@kde.org>

   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   This library is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
   License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to the
   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
*/

#ifndef __MIMETREEPARSER_BODYFORAMATTER_MULTIPARTENCRYPTED_H__
#define __MIMETREEPARSER_BODYFORAMATTER_MULTIPARTENCRYPTED_H__

#include "interfaces/bodypartformatter.h"
#include "interfaces/bodypart.h"

namespace MimeTreeParser
{

class MultiPartEncryptedBodyPartFormatter : public Interface::BodyPartFormatter
{
    static const MultiPartEncryptedBodyPartFormatter *self;
public:
    Interface::MessagePart::Ptr process(Interface::BodyPart &part) const Q_DECL_OVERRIDE;
    Interface::BodyPartFormatter::Result format(Interface::BodyPart *, HtmlWriter *) const Q_DECL_OVERRIDE;
    using Interface::BodyPartFormatter::format;
    static const Interface::BodyPartFormatter *create();
};

}

#endif

==> messagelib-17.08.0.tar.xz: messagelib-17.08.0/mimetreeparser/src/bodyformatter/multipartencrypted.h <==
/*
   Copyright (c) 2016 Sandro Knauß <sknauss@kde.org>

   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   This library is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
   License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to the
   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
*/

#ifndef __MIMETREEPARSER_BODYFORAMATTER_MULTIPARTENCRYPTED_H__
#define __MIMETREEPARSER_BODYFORAMATTER_MULTIPARTENCRYPTED_H__

#include "interfaces/bodypartformatter.h"
#include "interfaces/bodypart.h"

namespace MimeTreeParser
{

class MultiPartEncryptedBodyPartFormatter : public Interface::BodyPartFormatter
{
    static const MultiPartEncryptedBodyPartFormatter *self;
public:
    Interface::MessagePart::Ptr process(Interface::BodyPart &part) const override;
    Interface::BodyPartFormatter::Result format(Interface::BodyPart *, HtmlWriter *) const override;
    using Interface::BodyPartFormatter::format;
    static const Interface::BodyPartFormatter *create();
};

}

#endif
